/*
 * @(#)Options.h
 *
 * This file is part of webCDwriter - Network CD Writing.
 *
 * Copyright (C) 1999-2002 Jrg P. M. Haeger
 *
 * webCDwriter is free software. See CDWserver.cpp for details.
 *
 * Jrg Haeger, 25.04.2001
 */

/**
 * A container for the writing options.
 *
 * @version 20021008
 * @author Jrg P. M. Haeger
 */
struct Options {
	int protocolVersion;
	int audio;
	int blankTOC;
	const char *bootImage;
	int closeCD;
	int copies;
	int DAO;
	int HFS;
	int joliet;
	int laserOff;
	int burnOffline;
	int rockRidge;
	int speed;
	int verify;
	const char *volumeID;

	Options() {
		protocolVersion = 1;
		bootImage = NULL;
		volumeID = NULL;
		reset();
	}

	~Options() {
		reset();
	}

	void reset() {
		if (protocolVersion == 1) {
			closeCD = 1;
			joliet = 1;
			rockRidge = 1;
		}
		else {
			closeCD = 0;
			joliet = 0;
			rockRidge = 0;
		}
		audio = 0;
		blankTOC = 0;
		if (bootImage != NULL) {
			delete[] bootImage;
			bootImage = NULL;
		}
		burnOffline = 0;
		copies = 1;
		DAO = 0;
		HFS = 0;
		laserOff = 0;
		speed = config.getDefaultSpeed();
		verify = 0;
		if (volumeID != NULL) {
			delete[] volumeID;
			volumeID = NULL;
		}
	}

	void setVolumeID(const char *ID) {
		if (volumeID != NULL) {
			delete[] volumeID;
			volumeID = NULL;
		}
		volumeID = strDup(ID);
	}
};
